Struct ThreadMeta
Source pub struct ThreadMeta {
pub name: Arc<str>,
pub kernel_stack: Mapping<Stack, Kernel>,
pub state: AtomicThreadState,
pub thread_id: ThreadId,
pub address_space: AddressSpace,
pub handles: HandleMap,
pub async_map: Arc<AsyncMap>,
pub join_waiter: AtomicWaker,
}
Available on crate feature full only.
handles: HandleMap
Immutably borrows from an owned value.
Read more
Formats the value using the given formatter.
Read more
Executes the destructor for this type.
Read more
🔬This is a nightly-only experimental API. (pin_ergonomics)
Execute the destructor for this type, but different to
Drop::drop, it requires
self
to be pinned.
Read more
Wake this task.
Wake this task without consuming the waker.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.